version_info = (5, 3, 4)
__version__ = '.'.join(map(str, version_info[:3]))

# pep440 is annoying, beta/alpha/rc should _not_ have dots or pip/setuptools
# confuses which one between the wheel and sdist is the most recent.
if len(version_info) == 4:
    extra = version_info[3]
    if extra.startswith(('a','b','rc')):
        __version__ = __version__+extra
    else:
        __version__ = __version__+'.'+extra
if len(version_info) > 4:
    raise NotImplementedError

kernel_protocol_version_info = (5, 3)
kernel_protocol_version = '%s.%s' % kernel_protocol_version_info



""" Implements a fully blocking kernel client.

Useful for test suites and blocking terminal interfaces.
"""
#-----------------------------------------------------------------------------
#  Copyright (C) 2012  The IPython Development Team
#
#  Distributed under the terms of the BSD License.  The full license is in
#  the file COPYING.txt, distributed as part of this software.
#-----------------------------------------------------------------------------
import sys
try:
    from queue import Queue, Empty  # Py 3
except ImportError:
    from Queue import Queue, Empty  # Py 2

# IPython imports
from traitlets import Type

# Local imports
from .channels import (
    InProcessChannel,
)
from .client import InProcessKernelClient

class BlockingInProcessChannel(InProcessChannel):

    def __init__(self, *args, **kwds):
        super(BlockingInProcessChannel, self).__init__(*args, **kwds)
        self._in_queue = Queue()

    def call_handlers(self, msg):
        self._in_queue.put(msg)

    def get_msg(self, block=True, timeout=None):
        """ Gets a message if there is one that is ready. """
        if timeout is None:
            # Queue.get(timeout=None) has stupid uninteruptible
            # behavior, so wait for a week instead
            timeout = 604800
        return self._in_queue.get(block, timeout)

    def get_msgs(self):
        """ Get all messages that are currently ready. """
        msgs = []
        while True:
            try:
                msgs.append(self.get_msg(block=False))
            except Empty:
                break
        return msgs

    def msg_ready(self):
        """ Is there a message that has been received? """
        return not self._in_queue.empty()


class BlockingInProcessStdInChannel(BlockingInProcessChannel):
    def call_handlers(self, msg):
        """ Overridden for the in-process channel.

        This methods simply calls raw_input directly.
        """
        msg_type = msg['header']['msg_type']
        if msg_type == 'input_request':
            _raw_input = self.client.kernel._sys_raw_input
            prompt = msg['content']['prompt']
            print(prompt, end='', file=sys.__stdout__)
            sys.__stdout__.flush()
            self.client.input(_raw_input())

class BlockingInProcessKernelClient(InProcessKernelClient):

    # The classes to use for the various channels.
    shell_channel_class = Type(BlockingInProcessChannel)
    iopub_channel_class = Type(BlockingInProcessChannel)
    stdin_channel_class = Type(BlockingInProcessStdInChannel)

    def wait_for_ready(self):
        # Wait for kernel info reply on shell channel
        while True:
            msg = self.shell_channel.get_msg(block=True)
            if msg['msg_type'] == 'kernel_info_reply':
                self._handle_kernel_info_reply(msg)
                break

        # Flush IOPub channel
        while True:
            try:
                msg = self.iopub_channel.get_msg(block=True, timeout=0.2)
                print(msg['msg_type'])
            except Empty:
                break



import os
from pathlib import Path
import sys
import json

prefix = Path(os.environ["PREFIX"])
kernel = "python{}".format(sys.version_info[0])
spec_path = prefix / "share" / "jupyter" / "kernels" / kernel / "kernel.json"
posix_exe = Path(sys.executable).as_posix()

print("Rewriting kernelspec at:\n\t{}".format(spec_path))

raw_spec = spec_path.read_text()

print(raw_spec)

spec = json.loads(raw_spec)

print("Kernel python was:\n\t{}".format(spec["argv"][0]))

if spec["argv"][0] == posix_exe:
    print("Path is fine")
else:
    print("Rewriting kernel python with:\n\t{}".format(posix_exe))
    spec["argv"][0] = posix_exe
    spec_path.write_text(json.dumps(spec, indent=2))
